@@ -634,7 +634,7 @@ class TimeKeeper():
     def end(self) -> datetime:
         self.end_time = datetime.datetime.now()
         self.logs.append(self.end_time)
-        diff = self.end_time, self.start_time
+        diff = self.end_time - self.start_time
         if self.supress == 'y':
             pass
         else:
